@@ -21,7 +21,7 @@ import collections, datetime
 
 import dxpy
 from dxpy.utils.describe import get_field_from_jbor, get_job_from_jbor, is_job_ref, job_output_to_str, JOB_STATES
-from dxpy.utils.printing import (RED, GREEN, BLUE, BOLD, ENDC, fill)
+from dxpy.utils.printing import (GREEN, BLUE, BOLD, ENDC, fill)
 from dxpy.utils.resolver import is_localjob_id
 
 def exit_with_error(msg):
